# -*- coding: utf-8 -*-
# @author: leesoar

"""something."""
import sys

from crack.util import *


__version__ = "0.1.8"

if sys.version_info >= (3, 6):
    from secrets import *
